#include<stdio.h>
#include<jvmti.h>
#include<tijmp.h>

void JNICALL VMDeath (jvmtiEnv *jvmti_env, JNIEnv* jni_env) {
    fprintf (stdout, "tijmp: VMDeath called\n");
    tijmp_vm_death ();
}
